@extends(Config::get('manager::views.layouts.master'))

@section('content')
    <ul class="breadcrumb">
        <li><a href="{{ route('manager.home') }}">Home</a></li>
        <li><a href="{{ route('manager.press.index') }}">Imprensa</a></li>
        <li class="active">{{ $edit ? 'Editar' : 'Inserir' }}</li>
    </ul><!-- .breadcrumb -->

    <div class="page-header">
        <div class="pull-left">
            <h2>Imprensa</h2>
        </div><!-- .pull-left -->

        <div class="pull-right">
            <a href="{{ route('manager.press.index') }}" class="btn btn-default">Cancelar</a>
        </div><!-- .pull-right -->

        <div class="clearfix"></div>
    </div><!-- .page-header -->

    @include('manager::inc.messages')

    <form action="{{ ! $edit ? route('manager.press.store') : route('manager.press.update', $press->id) }}" method="post" id="form-press" class="form-horizontal" enctype="multipart/form-data">
        @if ($edit)
            <input type="hidden" name="_method" value="put" />
        @endif

        <fieldset>
            @section('fields')

                <div class="form-group">
                    <label for="title" class="col-sm-2 control-label">Título</label>

                    <div class="col-sm-8">
                        <input type="text" name="title" id="title" class="form-control" value="{{ $press->title }}" required autofocus />
                    </div><!-- .col-sm-8 -->
                </div><!-- .form-group -->

                <div class="form-group">
                    <label for="link" class="col-sm-2 control-label">Link</label>

                    <div class="col-sm-8">
                        <input type="text" name="link" id="link" class="form-control" value="{{ $press->link }}" required />
                    </div><!-- .col-sm-8 -->
                </div><!-- .form-group -->

                <div class="form-group">
                    <label for="date" class="col-sm-2 control-label">Data</label>

                    <div class="col-sm-2">
                        <div class="input-group">
                            <input type="text" name="date" id="date" class="form-control" value="{{ ($edit == true ? date('d/m/Y', strtotime(str_replace('-', '/', $press->date))) : '') }}" maxlength="255" required data-datepicker />
                            <span class="input-group-addon"><span class="glyphicon glyphicon-calendar"></span></span>
                        </div><!-- .input-append -->

                        <span class="help-block">dd/mm/aaaa</span>
                    </div><!-- .col-sm-8 -->
                </div><!-- .form-group -->

                <div class="form-group">
                    <label for="description" class="col-sm-2 control-label">Descrição</label>

                    <div class="col-sm-8">
                        <textarea  name="description" id="description" data-editor>{{ $press->description }}</textarea>
                    </div><!-- .col-sm-8 -->
                </div><!-- .form-group -->
                 <div class="form-group">
                    <label class="col-sm-2 control-label">Arquivos</label>

                    <div class="col-sm-8">
                        <input type="file" name="files[]" class="form-control" multiple />
                    </div><!-- .col-sm-8 -->
                </div><!-- .form-group -->

                @if ($press->downloads->count() > 0)
                    <div class="form-group">
                        <label class="col-sm-2 control-label">Arquivos desta matéria</label>

                        <div class="col-sm-8">
                            @foreach ($press->downloads as $download)
                                <p>
                                    <a href="{{ asset('files/downloads/' . $download->file) }}" class="btn" download="{{ $download->file }}" target="_blank">
                                        <i class="icon-download"></i> {{ $download->file }}
                                    </a>

                                    <a href="{{ route('manager.press.destroyFile', $download->id) }}" class="btn btn-danger js-btn-destroy-download" title="Excluir download" data-id="{{ $download->id }}" data-toggle="tooltip" data-loading-text="Excluindo..." data-delete>
                                        <span class="glyphicon glyphicon-trash glyphicon-white"></span>
                                    </a>
                                </p>
                            @endforeach
                        </div><!-- .col-sm-8 -->
                    </div><!-- .form-group -->
                @endif
            @show
        </fieldset>

        <div class="form-group">
            <div class="col-sm-offset-2 col-sm-10">
                <button type="submit" class="btn btn-primary" data-loading-text="Carregando...">Salvar</button>
                <a href="{{ route('manager.press.index') }}" class="btn">Cancelar</a>
            </div>
        </div><!-- .form-group -->
    </form>
@stop

@section('scripts')
    @parent

    <script>
    (function() {
        window.App = window.App || {};

        App.PressForm = {
            init: function() {
                this.fetchElements();
                this.bindUIEvents();
            },

            fetchElements: function() {
                this.$form              = $('#form-press');
                this.$btnSubmit         = this.$form.find('.js-btn-submit');
                this.$btnDeleteDownload = this.$form.find('.js-btn-destroy-download');
            },

            bindUIEvents: function() {
                var _this;
                _this = this;

                this.$form.on('submit', function(e) {
                    _this.$btnSubmit.button('loading').prop('disabled', true);
                });

                this.$btnDeleteDownload.on('click', function(e) {
                    var $btn;
                    $btn = $(this);
                    $btn.prop('disabled', true).button('loading');
                });
            }
        }

        App.PressForm.init();
    })();
    </script>
@stop
